import { Logger } from 'drizzle-orm';
import { Query } from 'drizzle-orm/sql';
import { SQLiteSyncDialect } from '../dialect';
import { SelectFieldsOrdered } from '../operations';
import { PreparedQuery as PreparedQueryBase, PreparedQueryConfig as PreparedQueryConfigBase, SQLiteSession } from '../session';
import { SQlite3WasmDb } from './driver';
export interface SQLiteWasmSessionOptions {
    logger?: Logger;
}
declare type PreparedQueryConfig = Omit<PreparedQueryConfigBase, 'statement' | 'run'>;
export declare class SQLiteWasmSession extends SQLiteSession<'sync', void> {
    private client;
    private logger;
    constructor(client: SQlite3WasmDb, dialect: SQLiteSyncDialect, options?: SQLiteWasmSessionOptions);
    exec(query: string): void;
    prepareQuery<T extends Omit<PreparedQueryConfig, 'run'>>(query: Query, fields?: SelectFieldsOrdered): PreparedQuery<T>;
    prepareOneTimeQuery<T extends Omit<PreparedQueryConfig, 'run'>>(query: Query, fields?: SelectFieldsOrdered): PreparedQuery<T>;
}
export declare class PreparedQuery<T extends PreparedQueryConfig = PreparedQueryConfig> extends PreparedQueryBase<{
    type: 'sync';
    run: void;
    all: T['all'];
    get: T['get'];
    values: T['values'];
}> {
    private stmt;
    private queryString;
    private params;
    private logger;
    private fields;
    private isOneTimeQuery;
    constructor(stmt: any, queryString: string, params: unknown[], logger: Logger, fields: SelectFieldsOrdered | undefined, isOneTimeQuery?: boolean);
    run(placeholderValues?: Record<string, unknown>): void;
    all(placeholderValues?: Record<string, unknown>): T['all'];
    get(placeholderValues?: Record<string, unknown>): T['get'];
    values(placeholderValues?: Record<string, unknown>): T['values'];
    free(): boolean;
}
export {};
//# sourceMappingURL=session.d.ts.map